@@ -45,13 +45,14 @@ _logger = getLogger(__name__)
 
 
 MetadataType = Dict[str, Union[str, int, float]]
+ApplyCallable = Callable[[pd.DataFrame], Union[pd.DataFrame, pd.Series, float]]
 
 
 def _read_file(  # pylint: disable=missing-return-doc
     fnames: str, required_cols: Tuple[str], *args: Any, **kwargs: Any
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """
-    Prepare data to initialize :class:`ScmRun` from a file.
+    Prepare data to initialize :class:`ScmRun <scmdata.run.ScmRun>` from a file.
 
     Parameters
     ----------
@@ -62,7 +63,7 @@ def _read_file(  # pylint: disable=missing-return-doc
 
     Returns
     -------
-    :obj:`pd.DataFrame`, :obj:`pd.DataFrame`
+    :class:`pandas.DataFrame`, :class:`pandas.DataFrame`
         First dataframe is the data. Second dataframe is metadata
     """
     _logger.info("Reading %s", fnames)
@@ -74,7 +75,7 @@ def _read_pandas(
     fname: str, *args: Any, lowercase_cols=False, **kwargs: Any
 ) -> pd.DataFrame:
     """
-    Read a file and return a :class:`pd.DataFrame`.
+    Read a file and return a :class:`pandas.DataFrame`.
 
     Parameters
     ----------
@@ -85,16 +86,16 @@ def _read_pandas(
         If True, convert the column names of the file to lowercase
 
     *args
-        Passed to :func:`pd.read_excel` if :obj:`fname` ends with '.xls' or
-        '.xslx, otherwise passed to :func:`pd.read_csv`.
+        Passed to :func:`pandas.read_excel` if :obj:`fname` ends with '.xls' or
+        '.xslx, otherwise passed to :func:`pandas.read_csv`.
 
     **kwargs
-        Passed to :func:`pd.read_excel` if :obj:`fname` ends with '.xls' or
-        '.xslx, otherwise passed to :func:`pd.read_csv`.
+        Passed to :func:`pandas.read_excel` if :obj:`fname` ends with '.xls' or
+        '.xslx, otherwise passed to :func:`pandas.read_csv`.
 
     Returns
     -------
-    :obj:`pd.DataFrame`
+    :class:`pandas.DataFrame`
         Read data
 
     Raises
@@ -134,8 +135,8 @@ def _format_data(  # pylint: disable=missing-return-doc
     df: Union[pd.DataFrame, pd.Series], required_cols: Tuple[str]
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """
-    Prepare data to initialize :class:`ScmRun` from :class:`pd.DataFrame` or
-    :class:`pd.Series`.
+    Prepare data to initialize :class:`ScmRun <scmdata.run.ScmRun>` from :class:`pandas.DataFrame` or
+    :class:`pandas.Series`.
 
     See docstring of :func:`ScmRun.__init__` for details.
 
@@ -146,7 +147,7 @@ def _format_data(  # pylint: disable=missing-return-doc
 
     Returns
     -------
-    :obj:`pd.DataFrame`, :obj:`pd.DataFrame`
+    :class:`pandas.DataFrame`, :class:`pandas.DataFrame`
         First dataframe is the data. Second dataframe is metadata.
 
     Raises
@@ -222,7 +223,10 @@ def _format_wide_data(df, required_cols):
                     extra_cols.append(i)  # some other string
 
     if not time_cols:
-        msg = "invalid column format, must contain some time (int, float or datetime) columns!"
+        msg = (
+            "invalid column format, must contain some time (int, float or datetime) "
+            "columns!"
+        )
         raise ValueError(msg)
 
     all_cols = set(tuple(required_cols) + tuple(extra_cols))
@@ -242,7 +246,7 @@ def _from_ts(
     **columns: Union[str, bool, float, int, List],
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """
-    Prepare data to initialize :class:`ScmRun` from wide timeseries.
+    Prepare data to initialize :class:`ScmRun <scmdata.run.ScmRun>` from wide timeseries.
 
     See docstring of :func:`ScmRun.__init__` for details.
 
@@ -331,29 +335,31 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         Parameters
         ----------
         data: Union[ScmRun, IamDataFrame, pd.DataFrame, np.ndarray, str]
-            If a :class:`ScmRun` object is provided, then a new
-            :obj:`ScmRun` is created with a copy of the values and metadata from :obj:`data`.
+            If a :class:`ScmRun <scmdata.run.ScmRun>` object is provided, then a new
+            :class:`ScmRun <scmdata.run.ScmRun>` is created with a copy of the values and metadata from :obj:
+            `data`.
 
-            A :class:`pd.DataFrame` with IAMC-format data columns (the result
-            from :func:`ScmRun.timeseries()`) can be provided without any additional
+            A :class:`pandas.DataFrame` with IAMC-format data columns (the result from
+            :func:`ScmRun.timeseries()`) can be provided without any additional
             :obj:`columns` and :obj:`index` information.
 
-            If a numpy array of timeseries data is provided, :obj:`columns` and :obj:`index`
-            must also be specified. The shape of the numpy array should be
-            ``(n_times, n_series)`` where `n_times` is the number of timesteps and `n_series`
-            is the number of time series.
+            If a numpy array of timeseries data is provided, :obj:`columns` and
+            :obj:`index` must also be specified. The shape of the numpy array should be
+            ``(n_times, n_series)`` where `n_times` is the number of timesteps and
+            `n_series` is the number of time series.
 
-            If a string is passed, data will be attempted to be read from file. Currently,
-            reading from CSV, gzipped CSV and Excel formatted files is supported.
+            If a string is passed, data will be attempted to be read from file.
+            Currently, reading from CSV, gzipped CSV and Excel formatted files is
+            supported.
 
         index: np.ndarray
             If :obj:`index` is not ``None``, then the :obj:`index` is used as the timesteps
             for run. All timeseries in the run use the same set of timesteps.
 
-            The values will be attempted to be converted to :class:`np.datetime[s]` values.
+            The values will be attempted to be converted to :class:`numpy.datetime[s]` values.
             Possible input formats include :
 
-            * :obj:`datetime.datetime`
+            * :class:`datetime.datetime`
             * :obj:`int` Start of year
             * :obj:`float` Decimal year
             * :obj:`str` Uses :func:`dateutil.parser`. Slow and should be avoided if possible
@@ -412,10 +418,12 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         Raises
         ------
         ValueError
-            * If you try to load from multiple files at once. If you wish to do this, please use :func:`scmdata.run.run_append` instead.
-            * Not specifying :obj:`index` and :obj:`columns` if :obj:`data` is a :obj:`numpy.ndarray`
+            * If you try to load from multiple files at once. If you wish to do this,
+                please use :func:`scmdata.run.run_append` instead.
+            * Not specifying :obj:`index` and :obj:`columns` if :obj:`data` is a
+                :class:`numpy.ndarray`
 
-        :obj:`scmdata.errors.MissingRequiredColumn`
+        :class:`scmdata.errors.MissingRequiredColumn`
             If metadata for :attr:`required_cols` is not found
 
         TypeError
@@ -488,7 +496,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
+        :class:`ScmRun <scmdata.run.ScmRun>`
             :func:`copy.deepcopy` of ``self``
         """
         ret = copy.copy(self)
@@ -537,7 +545,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         Notes
         -----
         If the meta values changes are applied to a filtered subset, the change will be reflected
-        in the original :obj:`ScmRun` object.
+        in the original :class:`ScmRun <scmdata.run.ScmRun>` object.
 
         .. code:: python
 
@@ -592,7 +600,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         value
             Values to write
 
-            If a list of values is provided, then the length of that :obj:`value` must be the same as the number of timeseries
+            If a list of values is provided, then the length of that :obj:`value` must
+            be the same as the number of timeseries
 
         Raises
         ------
@@ -613,11 +622,11 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
                 new_meta_index[key] = pd.Series(meta, dtype="category")
                 self._meta = pd.MultiIndex.from_frame(new_meta_index)
             else:
-                raise ValueError(
-                    "Invalid length for metadata, `{}`, must be 1 or equal to the number of timeseries, `{}`".format(
-                        len(meta), len(self)
-                    )
+                msg = (
+                    "Invalid length for metadata, `{}`, must be 1 or equal to the "
+                    "number of timeseries, `{}`"
                 )
+                raise ValueError(msg.format(len(meta), len(self)))
 
         if self._duplicated_meta():
             raise NonUniqueMetadataError(self.meta)
@@ -664,7 +673,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
                     use_pint = True
                 except KeyError:  # pragma: no cover # emergency valve
                     raise KeyError(
-                        "No `unit` column in your metadata, cannot perform operations with pint quantities"
+                        "No `unit` column in your metadata, cannot perform operations "
+                        "with pint quantities"
                     )
             else:
                 data = df.values
@@ -754,7 +764,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`scmdata.time.TimePoints`
+        :class:`scmdata.time.TimePoints`
         """
         return self._time_points
 
@@ -762,7 +772,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         self, meta=None, check_duplicated=True, time_axis=None, drop_all_nan_times=False
     ):
         """
-        Return the data with metadata as a :obj:`pd.DataFrame`.
+        Return the data with metadata as a :class:`pandas.DataFrame`.
 
         Parameters
         ----------
@@ -775,14 +785,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             duplicated metadata
 
         time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
-            Time axis to use for the output's columns. If ``None``,
-            :class:`datetime.datetime` objects will be used. If ``"year"``, the
-            year of each time point  will be used. If ``"year-month"``, the year
-            plus (month - 0.5) / 12  will be used. If
-            ``"days since 1970-01-01"``, the number of days since 1st Jan 1970
-            will be used (calculated using the :mod:`datetime` module). If
-            ``"seconds since 1970-01-01"``, the number of seconds  since 1st Jan
-            1970 will be used (calculated using the :mod:`datetime` module).
+            See :func:`long_data` for a description of the options.
 
         drop_all_nan_times : bool
             Should time points which contain only nan values be dropped? This operation is applied
@@ -790,7 +793,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
+        :class:`pandas.DataFrame`
             DataFrame with datetimes as columns and timeseries as rows.
             Metadata is in the index.
 
@@ -866,19 +869,25 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         Parameters
         ----------
         time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
-            Time axis to use for the output's columns. If `None`,
-            :class:`datetime.datetime` objects will be used. If `"year"`, the
-            year of each time point  will be used. If `"year-month", the year
-            plus (month - 0.5) / 12  will be used. If
-            `"days since 1970-01-01"`, the number of days  since 1st Jan 1970
-            will be used (calculated using the ``datetime``  module). If
-            `"seconds since 1970-01-01"`, the number of seconds  since 1st Jan
-            1970 will be used (calculated using the ``datetime`` module).
+            Time axis to use for the output's columns.
+
+            If ``None``, :class:`datetime.datetime` objects will be used.
+
+            If ``"year"``, the year of each time point  will be used.
+
+            If ``"year-month"``, the year plus (month - 0.5) / 12  will be used.
+
+            If ``"days since 1970-01-01"``, the number of days  since 1st Jan 1970
+            will be used (calculated using the :mod:`datetime`  module).
+
+            If ``"seconds since 1970-01-01"``, the number of seconds  since 1st Jan
+            1970 will be used (calculated using the :mod:`datetime` module).
 
         Returns
         -------
-        :obj:`pd.DataFrame`
-            :obj:`pd.DataFrame` containing the data in 'long form' (i.e. one observation per row).
+        :class:`pandas.DataFrame`
+            :class:`pandas.DataFrame` containing the data in 'long form' (i.e. one observation
+            per row).
         """
         out = self.timeseries(time_axis=time_axis).stack()
         out.name = "value"
@@ -904,13 +913,13 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         The values are returned such that each row is a different
         timeseries being a row and each column is a different time (although
-        no time information is included as a plain :obj:`np.ndarray` is
+        no time information is included as a plain :class:`numpy.ndarray` is
         returned).
 
         Returns
         -------
         np.ndarray
-            The array in the same shape as :py:obj:`ScmRun.shape`, that is
+            The array in the same shape as :meth:`ScmRun.shape`, that is
             ``(num_timeseries, num_timesteps)``.
         """
         return self._df.values.T
@@ -918,12 +927,12 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
     @property
     def empty(self) -> bool:
         """
-        Indicate whether :obj:`ScmRun` is empty i.e. contains no data
+        Indicate whether :class:`ScmRun <scmdata.run.ScmRun>` is empty i.e. contains no data
 
         Returns
         -------
         bool
-            If :obj:`ScmRun` is empty, return ``True``, if not return ``False``
+            If :class:`ScmRun <scmdata.run.ScmRun>` is empty, return ``True``, if not return ``False``
         """
         return np.equal(len(self), 0)
 
@@ -1036,16 +1045,16 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
               :class:`datetime.datetime`'s
               TODO: default to np.datetime64
 
-            - 'year', 'month', 'day', hour': takes an :class:`int` or list of
-              :class:`int`'s ('month' and 'day' also accept :class:`str` or list of
-              :class:`str`)
+            - 'year', 'month', 'day', hour': takes an :obj:`int` or list of
+              :obj:`int`'s ('month' and 'day' also accept :obj:`str` or list of
+              :obj:`str`)
 
             If ``regexp=True`` is included in :obj:`kwargs` then the pseudo-regexp
             syntax in :func:`pattern_match` is disabled.
 
         Returns
         -------
-        :obj:`ScmRun`
+        :class:`ScmRun <scmdata.run.ScmRun>`
             If not ``inplace``, return a new instance with the filtered data.
         """
         ret = copy.copy(self) if not inplace else self
@@ -1097,8 +1106,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`np.ndarray` of :class:`bool`, :obj:`np.ndarray` of :class:`bool`
-            Two boolean :class:`np.ndarray`'s. The first contains the columns to keep
+        :class:`numpy.ndarray` of :class:`bool`, :class:`numpy.ndarray` of :class:`bool`
+            Two boolean :class:`numpy.ndarray`'s. The first contains the columns to keep
             (i.e. which time points to keep). The second contains the rows to keep (i.e.
             which metadata matched the filters).
 
@@ -1187,7 +1196,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
+        :class:`pandas.DataFrame`
             Tail of :func:`self.timeseries()`
         """
         return self.timeseries().head(*args, **kwargs)
@@ -1206,7 +1215,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
+        :class:`pandas.DataFrame`
             Tail of :func:`self.timeseries()`
         """
         return self.timeseries().tail(*args, **kwargs)
@@ -1232,6 +1241,9 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             There is more than one unique value in the metadata column and
             ``no_duplicates`` is ``True``.
 
+        KeyError
+            If a ``meta`` column does not exist in the run's metadata
+
         Returns
         -------
         [List[Any], Any]
@@ -1269,8 +1281,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
-            A new :class:`ScmRun` containing the data interpolated onto the
+        :class:`ScmRun <scmdata.run.ScmRun>`
+            A new :class:`ScmRun <scmdata.run.ScmRun>` containing the data interpolated onto the
             :obj:`target_times` grid
         """
         # pylint: disable=protected-access
@@ -1322,8 +1334,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
-            New :class:`ScmRun` instance on a new time index
+        :class:`ScmRun <scmdata.run.ScmRun>`
+            New :class:`ScmRun <scmdata.run.ScmRun>` instance on a new time index
 
         Examples
         --------
@@ -1407,7 +1419,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         References
         ----------
         See the pandas documentation for
-        `resample <http://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.Series.resample.html>`
+        `resample <http://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.
+        Series.resample.html>`
         for more information about possible arguments.
         """
         orig_dts = self["time"]
@@ -1427,7 +1440,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         ----------
         rule : ["AC", "AS", "A"]
             How to take the time mean. The names reflect the pandas
-            `user guide <http://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#dateoffset-objects>`_
+            `user guide <http://pandas.pydata.org/pandas-docs/stable/user_guide/timeser
+            ies.html#dateoffset-objects>`_
             where they can, but only the options
             given above are supported. For clarity, if ``rule`` is ``'AC'``, then the
             mean is an annual mean i.e. each time point in the result is the mean of
@@ -1441,7 +1455,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
+        :class:`ScmRun <scmdata.run.ScmRun>`
             The time mean of ``self``.
         """
         if rule == "AS":
@@ -1493,7 +1507,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
     def process_over(
         self,
         cols: Union[str, List[str]],
-        operation: str,
+        operation: Union[str, ApplyCallable],
         na_override=-1e6,
         **kwargs: Any,
     ) -> pd.DataFrame:
@@ -1506,11 +1520,21 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             Columns to perform the operation on. The timeseries will be grouped by all
             other columns in :attr:`meta`.
 
-        operation : ['median', 'mean', 'quantile']
-            The operation to perform. This uses the equivalent pandas function. Note
-            that quantile means the value of the data at a given point in the cumulative
+        operation : str or func
+            The operation to perform.
+
+            If a string is provided, the equivalent pandas groupby function is used. Note
+            that not all groupby functions are available as some do not make sense for
+            this particular application. Additional information about the arguments for
+            the pandas groupby functions can be found at <https://pandas.pydata.org/pan
+            das-docs/stable/reference/groupby.html>`_.
+
+            If a function is provided, it will be applied to each group. The function must
+            take a dataframe as its first argument and return a DataFrame, Series or scalar.
+
+            Note that quantile means the value of the data at a given point in the cumulative
             distribution of values at each point in the timeseries, for each timeseries
-            once the groupby is applied. As a result, using ``q=0.5`` is is the same as
+            once the groupby is applied. As a result, using ``q=0.5`` is the same as
             taking the median and not the same as taking the mean/average.
 
         na_override: [int, float]
@@ -1527,14 +1551,14 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
+        :class:`pandas.DataFrame`
             The quantiles of the timeseries, grouped by all columns in :attr:`meta`
             other than :obj:`cols`
 
         Raises
         ------
         ValueError
-            If the operation is not one of ['median', 'mean', 'quantile']
+            If the operation is not an allowed operation
 
             If the value of na_override clashes with any existing metadata
         """
@@ -1550,20 +1574,43 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         group_cols = list(set(ts.index.names) - set(cols))
         grouper = ts.groupby(group_cols)
 
-        if operation == "median":
-            res = grouper.median(**kwargs)
-        elif operation == "mean":
-            res = grouper.mean(**kwargs)
-        elif operation == "quantile":
-            res = grouper.quantile(**kwargs)
+        # This is a subset of the available functions
+        #  https://pandas.pydata.org/pandas-docs/stable/reference/groupby.html
+        allowed_pd_ops = [
+            "count",
+            "cumcount",
+            "cummax",
+            "cummin",
+            "cumprod",
+            "cumsum",
+            "first",
+            "last",
+            "max",
+            "mean",
+            "median",
+            "min",
+            "prod",
+            "rank",
+            "std",
+            "sum",
+            "var",
+            "quantile",
+        ]
+
+        if isinstance(operation, str):
+            if operation not in allowed_pd_ops:
+                raise ValueError("invalid process_over operation")
+            grouper_func = getattr(grouper, operation)
+            res = grouper_func(**kwargs)
         else:
-            raise ValueError("operation must be one of ['median', 'mean', 'quantile']")
+            res = grouper.apply(operation, **kwargs)
 
         if na_override is not None:
             idx_df = res.index.to_frame()
             idx_df[idx_df == na_override] = np.nan
             res.index = pd.MultiIndex.from_frame(idx_df)
 
+        res = res.reorder_levels(sorted(res.index.names))
         return res
 
     def quantiles_over(
@@ -1591,7 +1638,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
+        :class:`pandas.DataFrame`
             The quantiles of the timeseries, grouped by all columns in :attr:`meta`
             other than :obj:`cols`. Each calculated quantile is given a label which is
             stored in the ``quantile`` column within the output index.
@@ -1628,7 +1675,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         """
         Group the object by unique metadata
 
-        Enables iteration over groups of data. For example, to iterate over each scenario in the object
+        Enables iteration over groups of data. For example, to iterate over each
+        scenario in the object
 
         .. code:: python
 
@@ -1657,7 +1705,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`RunGroupBy`
+        :class:`RunGroupBy`
             See the documentation for :class:`RunGroupBy` for more information
 
         """
@@ -1698,8 +1746,8 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
-            If :obj:`inplace` is not ``False``, a new :class:`ScmRun` instance
+        :class:`ScmRun <scmdata.run.ScmRun>`
+            If :obj:`inplace` is not ``False``, a new :class:`ScmRun <scmdata.run.ScmRun>` instance
             with the converted units.
 
         Notes
@@ -1733,7 +1781,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         to_convert = to_convert_filtered.filter(
             unit=unit, log_if_empty=False, keep=False
         )
-        to_not_convert = run_append([to_not_convert_filtered, already_correct_unit,])
+        to_not_convert = run_append([to_not_convert_filtered, already_correct_unit])
 
         if "unit_context" in to_convert.meta_attributes and not to_convert.empty:
             self._check_unit_context(to_convert, context)
@@ -1794,7 +1842,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
+        :class:`ScmRun <scmdata.run.ScmRun>`
             New object containing the timeseries, adjusted to the reference period mean.
             The reference period year bounds are stored in the meta columns
             ``"reference_period_start_year"`` and ``"reference_period_end_year"``.
@@ -1836,22 +1884,23 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         Parameters
         ----------
         other
-            Data (in format which can be cast to :class:`ScmRun`) to append
+            Data (in format which can be cast to :class:`ScmRun <scmdata.run.ScmRun>`) to append
 
         inplace
             If ``True``, append data in place and return ``None``. Otherwise, return a
-            new :class:`ScmRun` instance with the appended data.
+            new :class:`ScmRun <scmdata.run.ScmRun>` instance with the appended data.
 
         duplicate_msg
-            If ``True``, raise a :class:`scmdata.errors.NonUniqueMetadataError` error so the user
-            can see the duplicate timeseries. If ``False``, take the average
+            If ``True``, raise a :class:`scmdata.errors.NonUniqueMetadataError` error
+            so the user can see the duplicate timeseries. If ``False``, take the average
             and do not raise a warning or error. If ``"warn"``, raise a
             warning if duplicate data is detected.
 
         metadata
-            If not ``None``, override the metadata of the resulting :obj:`ScmRun` with ``metadata``.
-            Otherwise, the metadata for the runs are merged. In the case where there are duplicate
-            metadata keys, the values from the first run are used.
+            If not ``None``, override the metadata of the resulting :class:`ScmRun <scmdata.run.ScmRun>` with
+            ``metadata``. Otherwise, the metadata for the runs are merged. In the case
+            where there are duplicate metadata keys, the values from the first run are
+            used.
 
         **kwargs
             Keywords to pass to :func:`ScmRun.__init__` when reading
@@ -1859,14 +1908,15 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`ScmRun`
-            If not :obj:`inplace`, return a new :class:`ScmRun` instance
+        :class:`ScmRun <scmdata.run.ScmRun>`
+            If not :obj:`inplace`, return a new :class:`ScmRun <scmdata.run.ScmRun>` instance
             containing the result of the append.
 
         Raises
         ------
         NonUniqueMetadataError
-            If the appending results in timeseries with duplicate metadata and :attr:`duplicate_msg` is ``True``
+            If the appending results in timeseries with duplicate metadata and
+            :attr:`duplicate_msg` is ``True``
 
         """
         if not isinstance(other, ScmRun):
@@ -1919,10 +1969,11 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         """
         Apply a function along a given axis
 
-        This is to provide the GroupBy functionality in :func:`ScmRun.groupby` and is not generally called directly.
+        This is to provide the GroupBy functionality in :func:`ScmRun.groupby` and is
+        not generally called directly.
 
-        This implementation is very bare-bones - no reduction along the time time dimension is allowed and only the `dim`
-        parameter is used.
+        This implementation is very bare-bones - no reduction along the time time
+        dimension is allowed and only the `dim` parameter is used.
 
         Parameters
         ----------
@@ -1930,14 +1981,14 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         dim : str
             Ignored
         axis : int
-            The dimension along which the function is applied. The only valid value is 0 which corresponds to the along the
-            time-series dimension.
+            The dimension along which the function is applied. The only valid value is 0
+            which corresponds to the along the time-series dimension.
         kwargs
             Other parameters passed to `func`
 
         Returns
         -------
-        :obj:`ScmRun`
+        :class:`ScmRun <scmdata.run.ScmRun>`
 
         Raises
         ------
@@ -2008,12 +2059,12 @@ def run_append(
     Append together many objects.
 
     When appending many objects, it may be more efficient to call this routine once with
-    a list of :class:`ScmRun`'s, than using :func:`ScmRun.append` multiple times.
+    a list of :class:`ScmRun <scmdata.run.ScmRun>`'s, than using :func:`ScmRun.append` multiple times.
 
-    If timeseries with duplicate metadata are found, the timeseries are appended and values
-    falling on the same timestep are averaged if :obj:`duplicate_msg` is not "return". If
-    :obj:`duplicate_msg` is "return", then the result will contain the duplicated timeseries
-    for further inspection.
+    If timeseries with duplicate metadata are found, the timeseries are appended and
+    values falling on the same timestep are averaged if :obj:`duplicate_msg` is not
+    "return". If :obj:`duplicate_msg` is "return", then the result will contain the
+    duplicated timeseries for further inspection.
 
     .. code:: python
 
@@ -2039,8 +2090,8 @@ def run_append(
 
     Parameters
     ----------
-    runs: list of :class:`ScmRun`
-        The runs to append. Values will be attempted to be cast to :class:`ScmRun`.
+    runs: list of :class:`ScmRun <scmdata.run.ScmRun>`
+        The runs to append. Values will be attempted to be cast to :class:`ScmRun <scmdata.run.ScmRun>`.
 
     inplace
         If ``True``, then the operation updates the first item in :obj:`runs` and returns
@@ -2053,13 +2104,13 @@ def run_append(
         duplicate data is detected.
 
     metadata
-        If not ``None``, override the metadata of the resulting :obj:`ScmRun` with ``metadata``.
-        Otherwise, the metadata for the runs are merged. In the case where there are duplicate
-        metadata keys, the values from the first run are used.
+        If not ``None``, override the metadata of the resulting :class:`ScmRun <scmdata.run.ScmRun>` with
+        ``metadata``. Otherwise, the metadata for the runs are merged. In the case where
+        there are duplicate metadata keys, the values from the first run are used.
 
     Returns
     -------
-    :obj:`ScmRun`
+    :class:`ScmRun <scmdata.run.ScmRun>`
         If not :obj:`inplace`, the return value is the object containing the merged
         data. The resultant class will be determined by the type of the first object.
 
@@ -2067,7 +2118,7 @@ def run_append(
     ------
     TypeError
         If :obj:`inplace` is ``True`` but the first element in :obj:`dfs` is not an
-        instance of :class:`ScmRun`
+        instance of :class:`ScmRun <scmdata.run.ScmRun>`
 
         ``runs`` argument is not a list
 
